package org.kaoriha.jspbp;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * QueryString represents and manipulates query string of URL.
 * 
 * @author NAKAZATO Hajime
 */
public class QueryString {
	private Map<String, List<String>> queryMap = new HashMap<String, List<String>>();

	public QueryString() {
	}

	/**
	 * @param qs
	 *            Query string like "foo=a&bar=b".
	 */
	public QueryString(String qs) {
		String[] qa = qs.split("&");
		for (String q : qa) {
			String[] kv = q.split("=");
			if (kv.length == 2) {
				put(kv[0], kv[1]);
			}
		}
	}

	public void put(String name, String value) {
		if (queryMap.containsKey(name)) {
			List<String> sl = queryMap.get(name);
			sl.add(value);
		} else {
			List<String> sl = new ArrayList<String>();
			sl.add(value);
			queryMap.put(name, sl);
		}
	}

	/**
	 * @param base
	 *            Left side of '?'.
	 * @return URL string.
	 */
	public String build(String base) {
		if (queryMap.size() == 0) {
			return base;
		}

		StringBuilder sb = new StringBuilder(base);
		sb.append("?");
		for (Map.Entry<String, List<String>> entry : queryMap.entrySet()) {
			for (String v : entry.getValue()) {
				sb.append(entry.getKey());
				sb.append("=");
				sb.append(v);
				sb.append("&");
			}
		}
		if (sb.length() > 0) {
			sb.deleteCharAt(sb.length() - 1);
		}
		return sb.toString();
	}
}
